#!/usr/bin/python

# Programmer: Andrew Robert
# Function: Generic method to extract information from a queue manager
# This script is intended to be run from the command line to return values
# based on supplied keys
#
# Usage:
#
# inquiry.py {host}{port}{queue manager}{object name} {key(s)...}
#
# Example:
# 
# To check the current depth of a specified queue
#
# inquiry.py BONGO 1414 SNOOPY ALT.TEST.Q CurrentQDepth
#
#
# Version History:
# v1.0 - 04/06/05 - AAR - Initial revision 
# (Derivative work Based on Perl code by D. Boger)
#
#


import pymqi, CMQC, sys, os, string

#
# Key dictionary
#
valid_keys={'AlterationDate':'MQCA_ALTERATION_DATE',
'AlterationTime':'MQCA_ALTERATION_TIME',
'BackoutRequeueName':'MQCA_BACKOUT_REQ_Q_NAME',
'BackoutThreshold':'MQIA_BACKOUT_THRESHOLD',
'BaseQName':'MQCA_BASE_Q_NAME',
'ClusterDate':'MQCA_CLUSTER_DATE',
'ClusterName':'MQCA_CLUSTER_NAME',
'ClusterNamelist':'MQCA_CLUSTER_NAMELIST',
'ClusterQType':'MQIA_CLUSTER_Q_TYPE',
'ClusterTime':'MQCA_CLUSTER_TIME',
'CreationDate':'MQCA_CREATION_DATE',
'CreationTime':'MQCA_CREATION_TIME',
'CurrentQDepth':'MQIA_CURRENT_Q_DEPTH',
'DefBind':'MQIA_DEF_BIND',
'DefInputOpenOption':'MQIA_DEF_INPUT_OPEN_OPTION',
'DefPersistence':'MQIA_DEF_PERSISTENCE',
'DefPriority':'MQIA_DEF_PRIORITY',
'DefinitionType':'MQIA_DEFINITION_TYPE',
'DistLists':'MQIA_DIST_LISTS',
'HardenGetBackout':'MQIA_HARDEN_GET_BACKOUT',
'HighQDepth':'MQIA_HIGH_Q_DEPTH',
'InhibitGet':'MQIA_INHIBIT_GET',
'InhibitPut':'MQIA_INHIBIT_PUT',
'InitiationQName':'MQCA_INITIATION_Q_NAME',
'MaxMsgLength':'MQIA_MAX_MSG_LENGTH',
'MaxQDepth':'MQIA_MAX_Q_DEPTH',
'MsgDeliverySequence':'MQIA_MSG_DELIVERY_SEQUENCE',
'MsgDeqCount':'MQIA_MSG_DEQ_COUNT',
'MsgEnqCount':'MQIA_MSG_ENQ_COUNT',
'OpenInputCount':'MQIA_OPEN_INPUT_COUNT',
'OpenOutputCount':'MQIA_OPEN_OUTPUT_COUNT',
'ProcessName':'MQCA_PROCESS_NAME',
'QDepthHighEvent':'MQIA_Q_DEPTH_HIGH_EVENT',
'QDepthHighLimit':'MQIA_Q_DEPTH_HIGH_LIMIT',
'QDepthLowEvent':'MQIA_Q_DEPTH_LOW_EVENT',
'QDepthLowLimit':'MQIA_Q_DEPTH_LOW_LIMIT',
'QDepthMaxEvent':'MQIA_Q_DEPTH_MAX_EVENT',
'QDesc':'MQCA_Q_DESC',
'QMgrIdentifier':'MQCA_Q_MGR_IDENTIFIER',
'QMgrName':'MQCA_CLUSTER_Q_MGR_NAME',
'QName':'MQCA_Q_NAME',
'QNames':'MQCACF_Q_NAMES',
'QServiceInterval':'MQIA_Q_SERVICE_INTERVAL',
'QServiceIntervalEvent':'MQIA_Q_SERVICE_INTERVAL_EVENT',
'QType':'MQIA_Q_TYPE',
'RemoteQMgrName':'MQCA_REMOTE_Q_MGR_NAME',
'RemoteQName':'MQCA_REMOTE_Q_NAME',
'RetentionInterval':'MQIA_RETENTION_INTERVAL',
'Scope':'MQIA_SCOPE',
'Shareability':'MQIA_SHAREABILITY',
'TimeSinceReset':'MQIA_TIME_SINCE_RESET',
'TriggerControl':'MQIA_TRIGGER_CONTROL',
'TriggerData':'MQCA_TRIGGER_DATA',
'TriggerDepth':'MQIA_TRIGGER_DEPTH',
'TriggerMsgPriority':'MQIA_TRIGGER_MSG_PRIORITY',
'TriggerType':'MQIA_TRIGGER_TYPE',
'Usage':'MQIA_USAGE',
'XmitQName':'MQCA_XMIT_Q_NAME'}
#
# Test number of arguments passed
#
def test_num_arguments():
    if len(sys.argv) == 1:
        print '\n\t\tInsufficient arguments\n\n\n'
        print '\tStandard Usage:\n'
        print '\tinquiry.py {host}{port}{queue manager} {object} {key ... }\n'
        print '\n\tExample:\n'
        print '\tinquiry.py MQIDEV1 1415 ADMIN.TEST.Q CurrentQDepth\n\n'
        sys.exit(1)

#
# Test user supplied keys to ensure they are valid
#
def test_valid_keys(key):
    if valid_keys.has_key(key):
        return
    else:
        print '\n\t\t\tInvalid key',key,'\n\n\n'
        print '\tStandard Usage:\n'
        print '\tinquiry.py {host}{port}{queue manager} {object} {key ... }\n'
        print '\n\tExample:\n'
        print '\tinquiry.py MQIDEV1 1415 ADMIN.TEST.Q CurrentQDepth\n\n'
        sys.exit(1)

#
# Determine number of command line parameters passed to program
# and validate key options using called functions
#
test_num_arguments()
arg_array_size =len(sys.argv)
counter=5
while counter < arg_array_size:
    test_valid_keys(sys.argv[counter])
    counter = counter +1

#
# Automatically adjust passed values to upper case to reflect queue manager
# naming conventions
#
host = sys.argv[1]
quemgr = sys.argv[3]
object = sys.argv[4]
sys.argv[1] =host.upper()
sys.argv[3] =quemgr.upper()
sys.argv[4] =object.upper()

#
# Form and set the environmental variable for the connection
# 
command="SYSTEM.ADMIN.SVRCONN/TCP/"+sys.argv[1]+"("+sys.argv[2]+")"
os.environ['MQSERVER'] =command 

#
# Form and execute inquiry to queue manager on specified object
#
qmgr = pymqi.QueueManager()
q = pymqi.Queue(qmgr, sys.argv[4])
counter=5
while counter < arg_array_size:
    arg = 'q.inquire(CMQC.'+valid_keys[sys.argv[counter]]+')'
    print sys.argv[counter],":",eval(arg)
    counter = counter +1
